@@ -912,11 +912,8 @@ uint8_t
     hdb_binsrch_info->idx_size = 0;
     hdb_binsrch_info->idx_off = 0;
     hdb_binsrch_info->idx_llen = 0;
-    if (hdb_binsrch_info->idx_lbuf != NULL)
-    {
-        free(hdb_binsrch_info->idx_lbuf);
-        hdb_binsrch_info->idx_lbuf = NULL;
-    }
+    free(hdb_binsrch_info->idx_lbuf);
+    hdb_binsrch_info->idx_lbuf = NULL;
 
     if (tsk_verbose)
         tsk_fprintf(stderr, "hdb_idxfinalize: Sorting index\n");
@@ -1096,7 +1093,7 @@ int8_t
         tsk_error_reset();
         tsk_error_set_errno(TSK_ERR_HDB_ARG);
         tsk_error_set_errstr(
-            "%s: Hash passed is different size than expected (%d vs %Zd)",
+            "%s: Hash passed is different size than expected (%d vs %zd)",
             func_name, hdb_binsrch_info->hash_len, strlen(hash));
         return -1;
     }
@@ -1529,10 +1526,8 @@ void
         hdb_info->hDb = NULL;
     }
 
-    if (hdb_info->idx_fname) {
-        free(hdb_info->idx_fname);
-        hdb_info->idx_fname = NULL;
-    }
+    free(hdb_info->idx_fname);
+    hdb_info->idx_fname = NULL;
 
     if (hdb_info->hIdx) {
         fclose(hdb_info->hIdx);
@@ -1544,20 +1539,14 @@ void
         hdb_info->hIdxTmp = NULL;
     }
 
-    if (hdb_info->uns_fname) {
-        free(hdb_info->uns_fname);
-        hdb_info->uns_fname = NULL;
-    }
+    free(hdb_info->uns_fname);
+    hdb_info->uns_fname = NULL;
 
-    if (hdb_info->idx_lbuf) {
-        free(hdb_info->idx_lbuf);
-        hdb_info->idx_lbuf = NULL;
-    }
+    free(hdb_info->idx_lbuf);
+    hdb_info->idx_lbuf = NULL;
 
-    if (hdb_info->idx_offsets) {
-        free(hdb_info->idx_offsets);
-        hdb_info->idx_offsets = NULL;
-    }
+    free(hdb_info->idx_offsets);
+    hdb_info->idx_offsets = NULL;
 
     hdb_info_base_close(hdb_info_base);
 
